@@ -1,13 +1,13 @@
 use strict;
 use warnings;
 package BenchmarkAnything::Storage::Frontend::Lib;
-# git description: v0.005-6-ga3e7734
+# git description: v0.006-2-gccb6591
 
 BEGIN {
   $BenchmarkAnything::Storage::Frontend::Lib::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Basic functions to access a BenchmarkAnything store
-$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.006';
+$BenchmarkAnything::Storage::Frontend::Lib::VERSION = '0.007';
 use Scalar::Util 'reftype';
 
 
@@ -186,7 +186,7 @@ sub _read_config
         require YAML::Any;
 
         # don't look into user's homedir if we are running tests
-        my $default_cfgfile = $ENV{HARNESS_ACTIVE} ? undef : File::HomeDir->my_home . "/.benchmarkanything/default.cfg";
+        my $default_cfgfile = $ENV{HARNESS_ACTIVE} ? "t/benchmarkanything-tapper.cfg" : File::HomeDir->my_home . "/.benchmarkanything/default.cfg";
 
         # read file
         eval {
